from callback.Callback import Callback
from matrix_wrapper import *
from callback.callbacks import HelpCallback
from callback.callbacks.DiskUsageCallback import DiskUsageCallback
from callback.callbacks.ListDirectoriesCallback import ListDirectoriesCallback
from callback.callbacks.TimerCallback import TimerCallback
from callback.callbacks.TaskCallback import TaskCallback
from callback.callbacks.TaskGroupCallback import TaskGroupCallback



class HelpCallback(Callback):
    ACTION_NAME = "help"

    async def run(self, args: dict):
            await send_html(
        """
<h2>Help</h2>
<p>
<code>{}</code> prints all available commands<br/>
<code>{}</code> gets disk usage for a directory, multiple or no directories can be specified<br/>
Example: <code>{} path/to/dir path/to/dir2 .</code><br/>
<code>{}</code> lists all directories at given path<br/>
Example: <code>{} path/to/dir path/to/dir2 .</code><br/>
<code>{}</code> interacts with timers
<ul>
    <li><code>{}</code> gets all timers</li>
    <li>
        <code>{}</code> creates new timer
        <ul>
            <code>{}</code> (required) duration in seconds
            <code>{}</code> (required) this will be sent when timer is finished
        </ul>
    </li>
    <li>
        <code>{}</code> cancels a given timer
        <ul>
            <code>{}</code> (required) timer with this id will be deleted
        </ul>
    </li>
</ul><br/>
<code>{}</code> interacts with tasks
<ul>
    <li>
        <code>{}</code> creates new task
        <ul>
            <li><code>{}</code> (required) name for new task</li>
        </ul>
    </li>
    <li>
        <code>{}</code> gets tasks
        <ul>
            <li><code>{}</code> (optional) task with (recursive) subtasks</li>
            <li><code>{}</code> (optional,multiple) parent task ids, required when <code>{}</code></li>
        </ul>
    </li>
    <li>
        <code>{}</code> deletes task
        <ul>
            <li><code>{}</code> (required) id for task to delete</li>
        </ul>
    </li>
    <li>
        <code>{}</code> ticks task
        <ul>
            <li><code>{}</code> (required) id for task to tick</li>
        </ul>
    </li>
    <li>
        <code>{}</code> unticks task
        <ul>
            <li><code>{}</code> (required) id for task to untick</li>
        </ul>
    </li>
    <li>
        <code>{}</code> manually dumps all tasks to the backup file, shouldn't be necessary
    </li>
    <li>
        <code>{}</code> interacts with timers for a task
        <ul>
            <li>
                <code>{}</code> creates timer for a given task
                <ul>
                    <li><code>{}</code> (required) to which task the timer will be added</li>
                    <li><code>{}</code> (optional) text for timer</li>
                    <li><code>{}</code> (required) duration for timer</li>
                </ul>
            </li>
            <li>
                <code>{}</code> links timers to a given task
                <ul>
                    <li><code>{}</code> (required) id of task where timer is added</li>
                    <li><code>{}</code> (required,multiple) ids of timers to be added</li>
                </ul>
            </li>
            <li>
                <code>{}</code> gets all timers for a given task
                <ul>
                    <li><code>{}</code> (required) id of task where the timers will be queried
                </ul>
            </li>
        </ul>
    </li>
    <li>
        <code>{}</code> interacts with subtasks for a task
        <ul>
            <li>
                <code>{}</code> creates new subtasks
                <ul>
                    <li><code>{}</code> (required) id of the parent task</li>
                    <li><code>{}</code> (required,multiple) name of the subtask</li>
                </ul>
            </li>
            <li>
                <code>{}</code> links existing subtasks to a task 
                <ul>
                    <li><code>{}</code> (required) id of the parent task where subtask is added</li>
                    <li><code>{}</code> (required,multiple) ids of the subtasks to be added</li>
                </ul>
            </li>
            <li>
                <code>{}</code> unlinks subtasks from a task
                <ul>
                    <li><code>{}</code> (required) id of the parent task</li>
                    <li><code>{}</code> (required,multiple) ids uf subtasks to be removed</li>
                </ul>
            </li>
            <li>
                <code>{}</code> gets subtasks from a task
                <ul>
                    <li><code>{}</code> (required) id of the parent task where subtask is added</li>
                </ul>
            </li>
        </ul>
    </li>
</ul><br/>
<code>{}</code> interacts with taskgroups
<ul>
    <li>
        <code>{}</code> creates new taskgroups
        <ul>
            <li><code>{}</code> (required,multiple) name for new taskgroup</li>
        </ul>
    </li>
    <li>
        <code>{}</code> gets taskgroups
        <ul>
            <li><code>{}</code> (optional) if subgroups should be added</li>
            <li><code>{}</code> (optional,multiple) id of taskgroup, required when {} set</li>
            <li><code>{}</code> (optional) if tasks should be added only used when {} set</li>
        </ul>
    </li>
    <li>
        <code>{}</code> deletes taskgroups
        <ul>
            <li><code>{}</code> (required,multiple) id of taskgroup</li>
        </ul>
    </li>
    <li>
        <code>{}</code> interacts with tasks in taskgroups
        <ul>
            <li>
                <code>{}</code> creates tasks in taskgroup
                <ul>
                    <li><code>{}</code> (required) id of taskgroup</li>
                    <li><code>{}</code> (required,multiple) name of new tasks</li>
                </ul>
            </li>
            <li>
                <code>{}</code> gets tasks in taskgroup
                <ul>
                    <li><code>{}</code> (required) id of taskgroup</li>
                </ul>
            </li>
            <li>
                <code>{}</code> links existing tasks to a taskgroup
                <ul>
                    <li><code>{}</code> (required) id of taskgroup</li>
                    <li><code>{}</code> (required,multiple) ids of tasks to link</li>
                </ul>
            </li>
            <li>
                <code>{}</code> unlinks tasks from a taskgroup
                <ul>
                    <li><code>{}</code> (required) id of taskgroup</li>
                    <li><code>{}</code> (required,multiple) ids of tasks to unlink</li>
                </ul>
            </li>
        </ul>
    </li>
     <li>
        <code>{}</code> interacts with subgroups in taskgroups
        <ul>
            <li>
                <code>{}</code> creates new subgroups in taskgroup
                <ul>
                    <li><code>{}</code> (required) id of taskgroup</li>
                    <li><code>{}</code> (required,multiple) name of new subtaskgroups</li>
                </ul>
            </li>
            <li>
                <code>{}</code> gets subgroups in taskgroup
                <ul>
                    <li><code>{}</code> (required) id of taskgroup</li>
                </ul>
            </li>
            <li>
                <code>{}</code> links existing subgroups to taskgroup
                <ul>
                    <li><code>{}</code> (required) id of taskgroup</li>
                    <li><code>{}</code> (required,multiple) id of subgroup</li>
                </ul>
            </li>
            <li>
                <code>{}</code> unlinks subgroups from taskgroup
                <ul>
                    <li><code>{}</code> (required) id of taskgroup</li>
                    <li><code>{}</code> (required,multiple) id of subgroup</li>
                </ul>
            </li>
        </ul>
    </li>
</ul>
<br/>
Warning: unknown args will not be used
</p>
            """.format(
            HelpCallback.ACTION_NAME,
            DiskUsageCallback.ACTION_NAME, DiskUsageCallback.ACTION_NAME,
            ListDirectoriesCallback.ACTION_NAME, ListDirectoriesCallback.ACTION_NAME,
            TimerCallback.ACTION_NAME, Callback.GET_PARAM, Callback.CREATE_PARAM, Callback.DURATION_ARG, Callback.TEXT_ARG, Callback.CANCEL_PARAM, Callback.ID_ARG,
            TaskCallback.ACTION_NAME, Callback.CREATE_PARAM, Callback.NAME_ARG, Callback.GET_PARAM, Callback.SUBTASKS_ARG, Callback.ID_ARG, Callback.SUBTASKS_ARG, Callback.DELETE_PARAM, Callback.ID_ARG, Callback.TICK_PARAM, Callback.ID_ARG, Callback.UNTICK_PARAM, Callback.ID_ARG, Callback.DUMP_PARAM,
            Callback.TIMER_PARAM, Callback.CREATE_PARAM, Callback.TASK_ID_ARG, Callback.TEXT_ARG, Callback.DURATION_ARG, Callback.LINK_PARAM, Callback.TASK_ID_ARG, Callback.TIMER_ID_ARG, Callback.GET_PARAM, Callback.TASK_ID_ARG,
            Callback.SUBTASK_PARAM, Callback.CREATE_PARAM, Callback.TASK_ID_ARG, Callback.NAME_ARG, Callback.LINK_PARAM, Callback.TASK_ID_ARG, Callback.SUBTASK_ID_ARG, Callback.UNLINK_PARAM, Callback.TASK_ID_ARG, Callback.SUBTASK_ID_ARG, Callback.GET_PARAM, Callback.TASK_ID_ARG,
            TaskGroupCallback.ACTION_NAME, Callback.CREATE_PARAM, Callback.NAME_ARG, Callback.GET_PARAM, Callback.SUBGROUPS_ARG, Callback.ID_ARG, Callback.SUBGROUPS_ARG, Callback.SUBTASKS_ARG, Callback.SUBGROUPS_ARG, Callback.DELETE_PARAM, Callback.ID_ARG, 
            Callback.TASK_PARAM, Callback.CREATE_PARAM, Callback.TASKGROUP_ID_ARG, Callback.NAME_ARG, Callback.GET_PARAM, Callback.TASKGROUP_ID_ARG, Callback.LINK_PARAM, Callback.TASKGROUP_ID_ARG, Callback.TASK_ID_ARG, Callback.UNLINK_PARAM, Callback.TASKGROUP_ID_ARG, Callback.TASK_ID_ARG,
            Callback.SUBTASK_PARAM, Callback.CREATE_PARAM, Callback.TASKGROUP_ID_ARG, Callback.NAME_ARG, Callback.GET_PARAM, Callback.TASKGROUP_ID_ARG, Callback.LINK_PARAM, Callback.TASKGROUP_ID_ARG, Callback.SUBTASKGROUP_ID_ARG, Callback.UNLINK_PARAM, Callback.TASKGROUP_ID_ARG, Callback.SUBTASKGROUP_ID_ARG)
    )
